nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Wrnen

Enum Wrnen 

#[repr(u8)]
pub enum Wrnen { TWRNINT_RWRNINT_INACTIVE = 0, TWRNINT_RWRNINT_ACTIVE = 1, }

Variants



TWRNINT_RWRNINT_INACTIVE = 0

TWRNINT and RWRNINT bits are zero, independent of the values in the error counters.



TWRNINT_RWRNINT_ACTIVE = 1

TWRNINT and RWRNINT bits are set when the respective error counter transitions from less than 96 to greater than or equal to 96.

Implementations

Source

impl Wrnen

pub const fn from_bits(val: u8) -> Wrnen

pub const fn to_bits(self) -> u8